
🏗️ 🚧 This library is under construction!🚧
===========================================

Synecdoche: HyperNetworks in Haiku
===================================

Hi!

Synecdoche is a mini-library for JAX providing clean implementations of hypernetworks.

The name Synecdoche refers to the literary device in which a part of something is substituted for the whole; fittingly, the methods implemented in this library are based around substituting the weights for a much larger network with a smaller one that is easier to manipulate!


Creating a hypernetwork has never been so easy!